@@ -670,6 +670,10 @@ class DirectoryDistributive(Distributive):
             for obj in filter(lambda x: x['name'] not in skip, self.data):
                 target_path = path.join(self.directory, obj['target'])
                 if obj['type'] == 'bind':
+                    if not path.exists(target_path):
+                        self._makeDirectory(target_path)
+                    if not path.exists(obj['source']):
+                        self._makeDirectory(obj['source'])
                     self._mountToBind(obj['source'], target_path)
                 else:
                     self._mountToDirectory(obj['source'], target_path,
