@@ -135,7 +135,8 @@ class Wsdl(WsdlBase):
                                 normal=('os_install_x11_video_drv',
                                         'os_install_x11_composite',
                                         'os_install_x11_resolution_preferred',
-                                        'os_install_grub_terminal')),
+                                        'os_install_grub_terminal'),
+                                expert=('os_install_fb_resolution_preferred',)),
             lambda group: group(_("Update"),
                                 normal=('cl_install_autocheck_set',
                                         'cl_install_autocheck_interval',
@@ -315,6 +316,7 @@ class Wsdl(WsdlBase):
                             'os_install_x11_resolution_preferred',
                             'os_install_x11_composite'),
                     expert=(
+                        'os_install_fb_resolution_preferred',
                         'cl_templates_locate',
                         'cl_dispatch_conf',
                         'cl_verbose_set'),
